TypeFlag

Enum TypeFlag 

pub enum TypeFlag {
Show 16 variants NormalFile, HardLink, SymbolicLink, CharacterSpecial, BlockSpecial, Directory, Fifo, ContiguousFile, PaxGlobal, Pax, GnuDirectory, GnuLongLink, GnuLongName, GnuSparse, GnuVolumeHeader, VendorSpecific(u8),
}
Type of entry.

Variants



NormalFile

Regular file.

Hard link.

Symbolic link.



CharacterSpecial

Character device node.



BlockSpecial

Block device node.



Directory

Directory.



Fifo

FIFO node.



ContiguousFile

Contiguous file, usually the same as regular file.



PaxGlobal

Global PAX properties for all following regular entry.



Pax

PAX properties for the following regular entry.



GnuDirectory

GNU extension directory. It contains data records the names of files in this directory.

GNU extension for long linkname for the following regular entry.



GnuLongName

GNU extension for long pathname for the following regular entry.



GnuSparse

GNU extension for sparse regular file.



GnuVolumeHeader

GNU extension for tape/volume header name.



VendorSpecific(u8)

Other vendor specific typeflag.